@@ -10,15 +10,20 @@ package Tie::Redis::Candy::Array;
 
 use strict;
 use warnings;
-use Carp;
+use Carp qw(croak confess);
 use CBOR::XS qw(encode_cbor decode_cbor);
 use base 'Tie::Array';
 
-our $VERSION = '0.004';    # VERSION
+my $undef = encode_cbor(undef);
+
+our $VERSION = '1.000';    # VERSION
 
 sub TIEARRAY {
     my ( $class, $redis, $listname ) = @_;
 
+    croak "not a Redis instance: $redis"
+      unless ref($redis) =~ m{^(?:Test::Mock::)?Redis$};
+
     my $self = {
         list  => $listname,
         redis => $redis,
@@ -72,20 +77,15 @@ sub SHIFT {
 }
 
 sub UNSHIFT {
-    my ( $self, @values ) = shift;
-    $self->{redis}->lpush( $self->{list}, encode_cbor($_) ) for @values;
+    my ( $self, @values ) = @_;
+    $self->{redis}->lpush( $self->{list}, encode_cbor($_) ) for reverse @values;
 }
 
 sub SPLICE {
-    my ( $self, $offset, $length ) = @_;
-    confess "cannot replace elements in list (unimplemented)" if @_ > 3;
-    $self->lrange( $self->{list}, $offset, $length );
+    confess 'UNIMPLEMENTED';
 }
 
 sub EXTEND {
-    my ( $self, $count ) = @_;
-    $self->{redis}->rpush( $self->{list}, '' )
-      for ( $self->FETCHSIZE .. ( $count - 1 ) );
 }
 
 sub DESTROY {
@@ -103,7 +103,7 @@ Tie::Redis::Candy::Array - tie Perl arrays to Redis lists - the candy way
 
 =head1 VERSION
 
-version 0.004
+version 1.000
 
 =head1 SYNOPSYS
 
