@@ -10,22 +10,21 @@ package Tie::Redis::Candy::Hash;
 
 use strict;
 use warnings;
-use Carp;
+use Carp qw(croak);
 use CBOR::XS qw(encode_cbor decode_cbor);
 use base 'Tie::Hash';
 
-our $VERSION = '0.004';    # VERSION
+our $VERSION = '1.000';    # VERSION
 
 sub TIEHASH {
-    my ( $class, $redis, $prefix ) = @_;
+    my ( $class, $redis, $key ) = @_;
 
-    die "whaa: $redis" unless ref $redis eq 'Redis';
-
-    $prefix = $prefix ? $prefix . ':' : '';
+    croak "not a Redis instance: $redis"
+      unless ref($redis) =~ m{^(?:Test::Mock::)?Redis$};
 
     my $self = {
-        prefix => $prefix,
-        redis  => $redis,
+        key   => $key,
+        redis => $redis,
     };
 
     return bless( $self, $class );
@@ -33,47 +32,41 @@ sub TIEHASH {
 
 sub STORE {
     my ( $self, $key, $value ) = @_;
-    $self->{redis}->set( $self->{prefix} . $key, encode_cbor($value) );
+    $self->{redis}->hset( $self->{key}, $key, encode_cbor($value) );
 }
 
 sub FETCH {
     my ( $self, $key ) = @_;
-    my $data = $self->{redis}->get( $self->{prefix} . $key );
+    my $data = $self->{redis}->hget( $self->{key}, $key );
     return unless defined $data;
     decode_cbor($data);
 }
 
 sub FIRSTKEY {
     my $self = shift;
-    $self->{prefix_keys} = [ $self->{redis}->keys( $self->{prefix} . '*' ) ];
+    $self->{keys} = [ $self->{redis}->hkeys( $self->{key} ) ];
     $self->NEXTKEY;
 }
 
 sub NEXTKEY {
     my $self = shift;
-
-    my $key = shift @{ $self->{prefix_keys} };
-    return unless defined $key;
-
-    my $p = quotemeta $self->{prefix};
-    $key =~ s/^$p// if $p;
-    return $key;
+    shift @{ $self->{keys} };
 }
 
 sub EXISTS {
     my ( $self, $key ) = @_;
-    $self->{redis}->exists( $self->{prefix} . $key );
+    $self->{redis}->hexists( $self->{key}, $key );
 }
 
 sub DELETE {
     my ( $self, $key ) = @_;
-    $self->{redis}->del( $self->{prefix} . $key );
+    $self->{redis}->hdel( $self->{key}, $key );
 }
 
 sub CLEAR {
     my ($self) = @_;
-    $self->{redis}->del($_) for $self->{redis}->keys( $self->{prefix} . '*' );
-    $self->{prefix_keys} = [];
+    $self->{redis}->del( $self->{key} );
+    delete $self->{keys};
 }
 
 1;
@@ -88,7 +81,7 @@ Tie::Redis::Candy::Hash - tie Perl hashes to Redis hashes - the candy way
 
 =head1 VERSION
 
-version 0.004
+version 1.000
 
 =head1 DESCRIPTION
 
